# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import inspect
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class CustomClusterAddAPIPayload(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'agent_access_token': 'str',
        'cluster_config': 'OrmKernelClusterConfig',
        'kubernetes_ingress_endpoint': 'str',
        'kubernetes_namespace': 'str',
        'name': 'str'
    }

    attribute_map = {
        'agent_access_token': 'agent_access_token',
        'cluster_config': 'cluster_config',
        'kubernetes_ingress_endpoint': 'kubernetes_ingress_endpoint',
        'kubernetes_namespace': 'kubernetes_namespace',
        'name': 'name'
    }

    def __init__(self, agent_access_token=None, cluster_config=None, kubernetes_ingress_endpoint=None, kubernetes_namespace=None, name=None, local_vars_configuration=None):  # noqa: E501
        """CustomClusterAddAPIPayload - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._agent_access_token = None
        self._cluster_config = None
        self._kubernetes_ingress_endpoint = None
        self._kubernetes_namespace = None
        self._name = None
        self.discriminator = None

        self.agent_access_token = agent_access_token
        if cluster_config is not None:
            self.cluster_config = cluster_config
        self.kubernetes_ingress_endpoint = kubernetes_ingress_endpoint
        self.kubernetes_namespace = kubernetes_namespace
        self.name = name

    @property
    def agent_access_token(self):
        """Gets the agent_access_token of this CustomClusterAddAPIPayload.  # noqa: E501


        :return: The agent_access_token of this CustomClusterAddAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._agent_access_token

    @agent_access_token.setter
    def agent_access_token(self, agent_access_token):
        """Sets the agent_access_token of this CustomClusterAddAPIPayload.


        :param agent_access_token: The agent_access_token of this CustomClusterAddAPIPayload.  # noqa: E501
        :type agent_access_token: str
        """
        if self.local_vars_configuration.client_side_validation and agent_access_token is None:  # noqa: E501
            raise ValueError("Invalid value for `agent_access_token`, must not be `None`")  # noqa: E501

        self._agent_access_token = agent_access_token

    @property
    def cluster_config(self):
        """Gets the cluster_config of this CustomClusterAddAPIPayload.  # noqa: E501


        :return: The cluster_config of this CustomClusterAddAPIPayload.  # noqa: E501
        :rtype: OrmKernelClusterConfig
        """
        return self._cluster_config

    @cluster_config.setter
    def cluster_config(self, cluster_config):
        """Sets the cluster_config of this CustomClusterAddAPIPayload.


        :param cluster_config: The cluster_config of this CustomClusterAddAPIPayload.  # noqa: E501
        :type cluster_config: OrmKernelClusterConfig
        """

        self._cluster_config = cluster_config

    @property
    def kubernetes_ingress_endpoint(self):
        """Gets the kubernetes_ingress_endpoint of this CustomClusterAddAPIPayload.  # noqa: E501


        :return: The kubernetes_ingress_endpoint of this CustomClusterAddAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._kubernetes_ingress_endpoint

    @kubernetes_ingress_endpoint.setter
    def kubernetes_ingress_endpoint(self, kubernetes_ingress_endpoint):
        """Sets the kubernetes_ingress_endpoint of this CustomClusterAddAPIPayload.


        :param kubernetes_ingress_endpoint: The kubernetes_ingress_endpoint of this CustomClusterAddAPIPayload.  # noqa: E501
        :type kubernetes_ingress_endpoint: str
        """

        self._kubernetes_ingress_endpoint = kubernetes_ingress_endpoint

    @property
    def kubernetes_namespace(self):
        """Gets the kubernetes_namespace of this CustomClusterAddAPIPayload.  # noqa: E501


        :return: The kubernetes_namespace of this CustomClusterAddAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._kubernetes_namespace

    @kubernetes_namespace.setter
    def kubernetes_namespace(self, kubernetes_namespace):
        """Sets the kubernetes_namespace of this CustomClusterAddAPIPayload.


        :param kubernetes_namespace: The kubernetes_namespace of this CustomClusterAddAPIPayload.  # noqa: E501
        :type kubernetes_namespace: str
        """
        if self.local_vars_configuration.client_side_validation and kubernetes_namespace is None:  # noqa: E501
            raise ValueError("Invalid value for `kubernetes_namespace`, must not be `None`")  # noqa: E501

        self._kubernetes_namespace = kubernetes_namespace

    @property
    def name(self):
        """Gets the name of this CustomClusterAddAPIPayload.  # noqa: E501


        :return: The name of this CustomClusterAddAPIPayload.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CustomClusterAddAPIPayload.


        :param name: The name of this CustomClusterAddAPIPayload.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = inspect.getargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CustomClusterAddAPIPayload):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CustomClusterAddAPIPayload):
            return True

        return self.to_dict() != other.to_dict()



from datetime import datetime, timezone

import timeago


def parse_time_to_ago(dt: datetime):
    if not dt:
        return "N/A"
    return timeago.format(dt, datetime.now(timezone.utc))


def safe_cast(val, to_type, default=None):
    try:
        return to_type(val)
    except (ValueError, TypeError):
        return default
